pub struct Config {
pub current_context: Option<String>,
pub preferences: Option<Mapping>,
pub clusters: Vec<Cluster>,
pub contexts: Vec<Context>,
pub users: Vec<User>,
pub api_version: Option<String>,
pub kind: Option<String>,
}Expand description
The main struct that holds the entire config map. See the methods on this struct for ways to parse a config.
Fields
current_context: Option<String>The name of the current active context. The actual context can be retrieved by finding the context in the context set based on this name.
preferences: Option<Mapping>Preferences provided in the config.yml file.
clusters: Vec<Cluster>The clusters as defined by the “clusters” key
contexts: Vec<Context>The contexts as defined by the “contexts” key
users: Vec<User>The users as defined by the “users” key
api_version: Option<String>Will typically be “v1”, generally not needed
kind: Option<String>Will typically be “Config”, generally not needed
Implementations
Sourceimpl Config
impl Config
Sourcepub fn load_default() -> Result<Config>
pub fn load_default() -> Result<Config>
Fetches the current config based on the user’s configured environment.
This includes $KUBECONFIG when set, or simply $HOME/.kube/config
otherwise.
TODO: Support multiple kubeconfig files in the KUBECONFIG env var
separated by colons, i.e. KUBECONFIG=file1:file2. Merge the result.
Sourcepub fn load<P: AsRef<Path>>(path: P) -> Result<Config>
pub fn load<P: AsRef<Path>>(path: P) -> Result<Config>
Fetches the config from the provided path.
Sourcepub fn get_current_context(&self) -> Option<&Context>
pub fn get_current_context(&self) -> Option<&Context>
Gets the currently active context based on the current-context key in
the config file.